<?php

namespace Drupal\ayrshare_node\Form;

use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a form for Ayrshare API Analytics action.
 */
class AnalyticsForm extends AyrshareBaseForm {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ayrshare_node_analytics_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $node = NULL) {
    $form = parent::buildForm($form, $form_state);
    $form['actions']['submit']['#value'] = $this->t('Get Analytics');
    $form['nid']['#value'] = $node;

    if ($analytics_data = $form_state->get('analytics_data')) {
      $form['analytics_data'] = [
        '#markup' => "<pre>$analytics_data</pre>",
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    if ($nid = $form_state->getValue('nid')) {
      $tid = $this->databaseStorage->find('post', $nid);
      $platforms = array_values($form_state->getValue('platforms'));
      $platforms = array_filter($platforms);
      $platforms_analytics_data = $this->apiClient->analyticsPost($tid, $platforms);

      if (!empty($platforms_analytics_data)) {
        $tid = $platforms_analytics_data['id'];

        foreach ($platforms_analytics_data as $platform_data) {
          if (is_array($platform_data)) {
            $fields = [
              'tid' => $tid,
              'pid' => $platform_data['id'],
              'nid' => $nid,
              'data' => serialize($platform_data['analytics']),
            ];

            $this->databaseStorage->insert('analytics', $fields, [
              'name' => 'pid',
              'value' => $platform_data['id'],
            ]);
          }
        }
      }

      $analytics_data = json_encode($platforms_analytics_data,
        JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE
      );
      $form_state->set('analytics_data', $analytics_data);
      $form_state->setRebuild();
    }
  }

}
